@@ -53,6 +53,7 @@ def train_model(model,
                 distributed=False,
                 validate=False,
                 timestamp=None,
+                device='cuda',
                 meta=None):
     logger = get_root_logger(cfg.log_level)
 
@@ -82,8 +83,13 @@ def train_model(model,
             broadcast_buffers=False,
             find_unused_parameters=find_unused_parameters)
     else:
-        model = MMDataParallel(
-            model.cuda(cfg.gpu_ids[0]), device_ids=cfg.gpu_ids)
+        if device == 'cuda':
+            model = MMDataParallel(
+                model.cuda(cfg.gpu_ids[0]), device_ids=cfg.gpu_ids)
+        elif device == 'cpu':
+            model = MMDataParallel(model.cpu())
+        else:
+            raise ValueError(F'unsupported device name {device}.')
 
     # build runner
     optimizer = build_optimizer(model, cfg.optimizer)
