@@ -5,11 +5,13 @@ from .dataset_wrappers import (ClassBalancedDataset, ConcatDataset,
                                RepeatDataset)
 from .imagenet import ImageNet
 from .mnist import MNIST, FashionMNIST
+from .multi_label import MultiLabelDataset
 from .samplers import DistributedSampler
+from .voc import VOC
 
 __all__ = [
     'BaseDataset', 'ImageNet', 'CIFAR10', 'CIFAR100', 'MNIST', 'FashionMNIST',
-    'build_dataloader', 'build_dataset', 'Compose', 'DistributedSampler',
-    'ConcatDataset', 'RepeatDataset', 'ClassBalancedDataset', 'DATASETS',
-    'PIPELINES'
+    'VOC', 'MultiLabelDataset', 'build_dataloader', 'build_dataset', 'Compose',
+    'DistributedSampler', 'ConcatDataset', 'RepeatDataset',
+    'ClassBalancedDataset', 'DATASETS', 'PIPELINES'
 ]
