@@ -88,7 +88,7 @@ class RandomCrop(object):
 
         ymin = random.randint(0, height - target_height)
         xmin = random.randint(0, width - target_width)
-        return xmin, ymin, target_height, target_width
+        return ymin, xmin, target_height, target_width
 
     def __call__(self, results):
         """
@@ -119,7 +119,7 @@ class RandomCrop(object):
                     pad_val=self.pad_val,
                     padding_mode=self.padding_mode)
 
-            xmin, ymin, height, width = self.get_params(img, self.size)
+            ymin, xmin, height, width = self.get_params(img, self.size)
             results[key] = mmcv.imcrop(
                 img,
                 np.array([
@@ -144,44 +144,71 @@ class RandomResizedCrop(object):
     is made. This crop is finally resized to given size.
 
     Args:
-        size (sequence or int): Desired output size of the crop. If size is an
+        size (sequence | int): Desired output size of the crop. If size is an
             int instead of sequence like (h, w), a square crop (size, size) is
             made.
         scale (tuple): Range of the random size of the cropped image compared
-            to the original image. Default: (0.08, 1.0).
+            to the original image. Defaults to (0.08, 1.0).
         ratio (tuple): Range of the random aspect ratio of the cropped image
-            compared to the original image. Default: (3. / 4., 4. / 3.).
+            compared to the original image. Defaults to (3. / 4., 4. / 3.).
+        max_attempts (int): Maxinum number of attempts before falling back to
+            Central Crop. Defaults to 10.
+        efficientnet_style (bool): Whether to use efficientnet style Random
+            ResizedCrop. Defaults to False.
+        min_covered (Number): Minimum ratio of the cropped area to the original
+             area. Only valid if efficientnet_style is true. Defaults to 0.1.
+        crop_padding (int): The crop padding parameter in efficientnet style
+            center crop. Only valid if efficientnet_style is true.
+            Defaults to 32.
         interpolation (str): Interpolation method, accepted values are
-            'nearest', 'bilinear', 'bicubic', 'area', 'lanczos'. Default:
+            'nearest', 'bilinear', 'bicubic', 'area', 'lanczos'. Defaults to
             'bilinear'.
         backend (str): The image resize backend type, accpeted values are
-            `cv2` and `pillow`. Default: `cv2`.
+            `cv2` and `pillow`. Defaults to `cv2`.
     """
 
     def __init__(self,
                  size,
                  scale=(0.08, 1.0),
                  ratio=(3. / 4., 4. / 3.),
+                 max_attempts=10,
+                 efficientnet_style=False,
+                 min_covered=0.1,
+                 crop_padding=32,
                  interpolation='bilinear',
                  backend='cv2'):
-        if isinstance(size, (tuple, list)):
-            self.size = size
-        else:
+        if efficientnet_style:
+            assert isinstance(size, int)
             self.size = (size, size)
+            assert crop_padding >= 0
+        else:
+            if isinstance(size, (tuple, list)):
+                self.size = size
+            else:
+                self.size = (size, size)
         if (scale[0] > scale[1]) or (ratio[0] > ratio[1]):
             raise ValueError('range should be of kind (min, max). '
-                             f'But received {scale}')
+                             f'But received scale {scale} and rato {ratio}.')
+        assert min_covered >= 0, 'min_covered should be no less than 0.'
+        assert isinstance(max_attempts, int) and max_attempts >= 0, \
+            'max_attempts mush be of typle int and no less than 0.'
+        assert interpolation in ('nearest', 'bilinear', 'bicubic', 'area',
+                                 'lanczos')
         if backend not in ['cv2', 'pillow']:
             raise ValueError(f'backend: {backend} is not supported for resize.'
                              'Supported backends are "cv2", "pillow"')
 
-        self.interpolation = interpolation
         self.scale = scale
         self.ratio = ratio
+        self.max_attempts = max_attempts
+        self.efficientnet_style = efficientnet_style
+        self.min_covered = min_covered
+        self.crop_padding = crop_padding
+        self.interpolation = interpolation
         self.backend = backend
 
     @staticmethod
-    def get_params(img, scale, ratio):
+    def get_params(img, scale, ratio, max_attempts=10):
         """Get parameters for ``crop`` for a random sized crop.
 
         Args:
@@ -190,16 +217,18 @@ class RandomResizedCrop(object):
                 compared to the original image size.
             ratio (tuple): Range of the random aspect ratio of the cropped
                 image compared to the original image area.
+            max_attempts (int): Maxinum number of attempts before falling back
+                to central crop. Defaults to 10.
 
         Returns:
-            tuple: Params (xmin, ymin, target_height, target_width) to be
-                passed to ``crop`` for a random sized crop.
+            tuple: Params (ymin, xmin, ymax, xmax) to be passed to `crop` for
+                a random sized crop.
         """
         height = img.shape[0]
         width = img.shape[1]
         area = height * width
 
-        for _ in range(10):
+        for _ in range(max_attempts):
             target_area = random.uniform(*scale) * area
             log_ratio = (math.log(ratio[0]), math.log(ratio[1]))
             aspect_ratio = math.exp(random.uniform(*log_ratio))
@@ -210,7 +239,9 @@ class RandomResizedCrop(object):
             if 0 < target_width <= width and 0 < target_height <= height:
                 ymin = random.randint(0, height - target_height)
                 xmin = random.randint(0, width - target_width)
-                return xmin, ymin, target_height, target_width
+                ymax = ymin + target_height - 1
+                xmax = xmin + target_width - 1
+                return ymin, xmin, ymax, xmax
 
         # Fallback to central crop
         in_ratio = float(width) / float(height)
@@ -225,26 +256,114 @@ class RandomResizedCrop(object):
             target_height = height
         ymin = (height - target_height) // 2
         xmin = (width - target_width) // 2
-        return xmin, ymin, target_height, target_width
+        ymax = ymin + target_height - 1
+        xmax = xmin + target_width - 1
+        return ymin, xmin, ymax, xmax
+
+    # https://github.com/kakaobrain/fast-autoaugment/blob/master/FastAutoAugment/data.py # noqa
+    @staticmethod
+    def get_params_efficientnet_style(img,
+                                      size,
+                                      scale,
+                                      ratio,
+                                      max_attempts=10,
+                                      min_covered=0.1,
+                                      crop_padding=32):
+        """Get parameters for ``crop`` for a random sized crop in efficientnet
+        style.
 
-    def __call__(self, results):
-        """
         Args:
-            img (ndarray): Image to be cropped and resized.
+            img (ndarray): Image to be cropped.
+            size (sequence): Desired output size of the crop.
+            scale (tuple): Range of the random size of the cropped image
+                compared to the original image size.
+            ratio (tuple): Range of the random aspect ratio of the cropped
+                image compared to the original image area.
+            max_attempts (int): Maxinum number of attempts before falling back
+                to central crop. Defaults to 10.
+            min_covered (Number): Minimum ratio of the cropped area to the
+                original area. Only valid if efficientnet_style is true.
+                Defaults to 0.1.
+            crop_padding (int): The crop padding parameter in efficientnet
+                style center crop. Defaults to 32.
 
         Returns:
-            ndarray: Randomly cropped and resized image.
+            tuple: Params (ymin, xmin, ymax, xmax) to be passed to `crop` for
+                a random sized crop.
         """
+        height, width = img.shape[:2]
+        area = height * width
+        min_target_area = scale[0] * area
+        max_target_area = scale[1] * area
+
+        for _ in range(max_attempts):
+            aspect_ratio = random.uniform(*ratio)
+            min_target_height = int(
+                round(math.sqrt(min_target_area / aspect_ratio)))
+            max_target_height = int(
+                round(math.sqrt(max_target_area / aspect_ratio)))
+
+            if max_target_height * aspect_ratio > width:
+                max_target_height = int((width + 0.5 - 1e-7) / aspect_ratio)
+                if max_target_height * aspect_ratio > width:
+                    max_target_height -= 1
+
+            max_target_height = min(max_target_height, height)
+            min_target_height = min(max_target_height, min_target_height)
+
+            # slightly differs from tf inplementation
+            target_height = int(
+                round(random.uniform(min_target_height, max_target_height)))
+            target_width = int(round(target_height * aspect_ratio))
+            target_area = target_height * target_width
+
+            # slight differs from tf. In tf, if target_area > max_target_area,
+            # area will be recalculated
+            if (target_area < min_target_area or target_area > max_target_area
+                    or target_width > width or target_height > height
+                    or target_area < min_covered * area):
+                continue
+
+            ymin = random.randint(0, height - target_height)
+            xmin = random.randint(0, width - target_width)
+            ymax = ymin + target_height - 1
+            xmax = xmin + target_width - 1
+
+            return ymin, xmin, ymax, xmax
+
+        # Fallback to central crop
+        img_short = min(height, width)
+        crop_size = size[0] / (size[0] + crop_padding) * img_short
+
+        ymin = max(0, int(round((height - crop_size) / 2.)))
+        xmin = max(0, int(round((width - crop_size) / 2.)))
+        ymax = min(height, ymin + crop_size) - 1
+        xmax = min(width, xmin + crop_size) - 1
+
+        return ymin, xmin, ymax, xmax
+
+    def __call__(self, results):
         for key in results.get('img_fields', ['img']):
             img = results[key]
-            xmin, ymin, target_height, target_width = self.get_params(
-                img, self.scale, self.ratio)
-            img = mmcv.imcrop(
-                img,
-                np.array([
-                    xmin, ymin, xmin + target_width - 1,
-                    ymin + target_height - 1
-                ]))
+            if self.efficientnet_style:
+                get_params_func = self.get_params_efficientnet_style
+                get_params_args = dict(
+                    img=img,
+                    size=self.size,
+                    scale=self.scale,
+                    ratio=self.ratio,
+                    max_attempts=self.max_attempts,
+                    min_covered=self.min_covered,
+                    crop_padding=self.crop_padding)
+            else:
+                get_params_func = self.get_params
+                get_params_args = dict(
+                    img=img,
+                    scale=self.scale,
+                    ratio=self.ratio,
+                    max_attempts=self.max_attempts)
+            ymin, xmin, ymax, xmax = get_params_func(**get_params_args)
+            img = mmcv.imcrop(img, bboxes=np.array([xmin, ymin, xmax, ymax]))
             results[key] = mmcv.imresize(
                 img,
                 tuple(self.size[::-1]),
@@ -253,11 +372,16 @@ class RandomResizedCrop(object):
         return results
 
     def __repr__(self):
-        format_string = self.__class__.__name__ + f'(size={self.size}'
-        format_string += f', scale={tuple(round(s, 4) for s in self.scale)}'
-        format_string += f', ratio={tuple(round(r, 4) for r in self.ratio)}'
-        format_string += f', interpolation={self.interpolation})'
-        return format_string
+        repr_str = self.__class__.__name__ + f'(size={self.size}'
+        repr_str += f', scale={tuple(round(s, 4) for s in self.scale)}'
+        repr_str += f', ratio={tuple(round(r, 4) for r in self.ratio)}'
+        repr_str += f', max_attempts={self.max_attempts}'
+        repr_str += f', efficientnet_style={self.efficientnet_style}'
+        repr_str += f', min_covered={self.min_covered}'
+        repr_str += f', crop_padding={self.crop_padding}'
+        repr_str += f', interpolation={self.interpolation}'
+        repr_str += f', backend={self.backend})'
+        return repr_str
 
 
 @PIPELINES.register_module()
@@ -564,22 +688,63 @@ class Resize(object):
 
 @PIPELINES.register_module()
 class CenterCrop(object):
-    """Center crop the image.
+    r"""Center crop the image.
 
     Args:
-        crop_size (int | tuple): Expected size after cropping, (h, w).
+        crop_size (int | tuple): Expected size after cropping with the format
+            of (h, w).
+        efficientnet_style (bool): Whether to use efficientnet style center
+            crop. Defaults to False.
+        crop_padding (int): The crop padding parameter in efficientnet style
+            center crop. Only valid if efficientnet style is True. Defaults to
+            32.
+        interpolation (str): Interpolation method, accepted values are
+            'nearest', 'bilinear', 'bicubic', 'area', 'lanczos'. Only valid if
+             efficientnet style is True. Defaults to 'bilinear'.
+        backend (str): The image resize backend type, accpeted values are
+            `cv2` and `pillow`. Only valid if efficientnet style is True.
+            Defaults to `cv2`.
+
 
     Notes:
-        If the image is smaller than the crop size, return the original image
+        If the image is smaller than the crop size, return the original image.
+        If efficientnet_style is set to False, the pipeline would be a simple
+        center crop using the crop_size.
+        If efficientnet_style is set to True, the pipeline will be to first to
+        perform the center crop with the crop_size_ as:
+
+        .. math::
+        crop\_size\_ = crop\_size / (crop\_size + crop\_padding) * short\_edge
+
+        And then the pipeline resizes the img to the input crop size.
     """
 
-    def __init__(self, crop_size):
-        assert isinstance(crop_size, int) or (isinstance(crop_size, tuple)
-                                              and len(crop_size) == 2)
+    def __init__(self,
+                 crop_size,
+                 efficientnet_style=False,
+                 crop_padding=32,
+                 interpolation='bilinear',
+                 backend='cv2'):
+        if efficientnet_style:
+            assert isinstance(crop_size, int)
+            assert crop_padding >= 0
+            assert interpolation in ('nearest', 'bilinear', 'bicubic', 'area',
+                                     'lanczos')
+            if backend not in ['cv2', 'pillow']:
+                raise ValueError(
+                    f'backend: {backend} is not supported for '
+                    'resize. Supported backends are "cv2", "pillow"')
+        else:
+            assert isinstance(crop_size, int) or (isinstance(crop_size, tuple)
+                                                  and len(crop_size) == 2)
         if isinstance(crop_size, int):
             crop_size = (crop_size, crop_size)
         assert crop_size[0] > 0 and crop_size[1] > 0
         self.crop_size = crop_size
+        self.efficientnet_style = efficientnet_style
+        self.crop_padding = crop_padding
+        self.interpolation = interpolation
+        self.backend = backend
 
     def __call__(self, results):
         crop_height, crop_width = self.crop_size[0], self.crop_size[1]
@@ -588,6 +753,14 @@ class CenterCrop(object):
             # img.shape has length 2 for grayscale, length 3 for color
             img_height, img_width = img.shape[:2]
 
+            # https://github.com/tensorflow/tpu/blob/master/models/official/efficientnet/preprocessing.py#L118 # noqa
+            if self.efficientnet_style:
+                img_short = min(img_height, img_width)
+                crop_height = crop_height / (crop_height +
+                                             self.crop_padding) * img_short
+                crop_width = crop_width / (crop_width +
+                                           self.crop_padding) * img_short
+
             y1 = max(0, int(round((img_height - crop_height) / 2.)))
             x1 = max(0, int(round((img_width - crop_width) / 2.)))
             y2 = min(img_height, y1 + crop_height) - 1
@@ -595,6 +768,13 @@ class CenterCrop(object):
 
             # crop the image
             img = mmcv.imcrop(img, bboxes=np.array([x1, y1, x2, y2]))
+
+            if self.efficientnet_style:
+                img = mmcv.imresize(
+                    img,
+                    tuple(self.crop_size[::-1]),
+                    interpolation=self.interpolation,
+                    backend=self.backend)
             img_shape = img.shape
             results[key] = img
         results['img_shape'] = img_shape
@@ -602,7 +782,12 @@ class CenterCrop(object):
         return results
 
     def __repr__(self):
-        return self.__class__.__name__ + f'(crop_size={self.crop_size})'
+        repr_str = self.__class__.__name__ + f'(crop_size={self.crop_size}'
+        repr_str += f', efficientnet_style={self.efficientnet_style}'
+        repr_str += f', crop_padding={self.crop_padding}'
+        repr_str += f', interpolation={self.interpolation}'
+        repr_str += f', backend={self.backend})'
+        return repr_str
 
 
 @PIPELINES.register_module()
