@@ -2,7 +2,9 @@ from .cls_head import ClsHead
 from .linear_head import LinearClsHead
 from .multi_label_head import MultiLabelClsHead
 from .multi_label_linear_head import MultiLabelLinearClsHead
+from .vision_transformer_head import VisionTransformerClsHead
 
 __all__ = [
-    'ClsHead', 'LinearClsHead', 'MultiLabelClsHead', 'MultiLabelLinearClsHead'
+    'ClsHead', 'LinearClsHead', 'MultiLabelClsHead', 'MultiLabelLinearClsHead',
+    'VisionTransformerClsHead'
 ]
