@@ -1,4 +1,6 @@
 from .channel_shuffle import channel_shuffle
+from .cutmix import BatchCutMixLayer
+from .helpers import to_2tuple, to_3tuple, to_4tuple, to_ntuple
 from .inverted_residual import InvertedResidual
 from .make_divisible import make_divisible
 from .mixup import BatchMixupLayer
@@ -6,5 +8,6 @@ from .se_layer import SELayer
 
 __all__ = [
     'channel_shuffle', 'make_divisible', 'InvertedResidual', 'BatchMixupLayer',
-    'SELayer'
+    'BatchCutMixLayer', 'SELayer', 'to_ntuple', 'to_2tuple', 'to_3tuple',
+    'to_4tuple'
 ]
